@@ -7,8 +7,6 @@
 
 #include <ctype.h>
 
-#define FF_OS_NUM_FORMAT_ARGS 12
-
 static void buildOutputDefault(const FFOSResult* os, FFstrbuf* result)
 {
     //Create the basic output
@@ -53,38 +51,6 @@ static void buildOutputDefault(const FFOSResult* os, FFstrbuf* result)
         ffStrbufAppend(result, &os->variantID);
         ffStrbufAppendC(result, ')');
     }
-
-    //Append architecture if it is missing
-    if(!ffStrbufContainIgnCase(result, &instance.state.platform.sysinfo.architecture))
-    {
-        ffStrbufAppendC(result, ' ');
-        ffStrbufAppend(result, &instance.state.platform.sysinfo.architecture);
-    }
-}
-
-static void buildOutputNixOS(const FFOSResult* os, FFstrbuf* result)
-{
-    ffStrbufAppendS(result, "NixOS");
-
-    if(os->buildID.length > 0)
-    {
-        ffStrbufAppendC(result, ' ');
-        ffStrbufAppend(result, &os->buildID);
-    }
-
-    if(os->codename.length > 0)
-    {
-        ffStrbufAppendS(result, " (");
-        ffStrbufAppendC(result, (char) toupper(os->codename.chars[0]));
-        ffStrbufAppendS(result, os->codename.chars + 1);
-        ffStrbufAppendC(result, ')');
-    }
-
-    if(instance.state.platform.sysinfo.architecture.length > 0)
-    {
-        ffStrbufAppendC(result, ' ');
-        ffStrbufAppend(result, &instance.state.platform.sysinfo.architecture);
-    }
 }
 
 void ffPrintOS(FFOSOptions* options)
@@ -101,17 +67,24 @@ void ffPrintOS(FFOSOptions* options)
     {
         FF_STRBUF_AUTO_DESTROY result = ffStrbufCreate();
 
-        if(ffStrbufIgnCaseCompS(&os->id, "nixos") == 0)
-            buildOutputNixOS(os, &result);
+        if(os->prettyName.length > 0)
+            ffStrbufAppend(&result, &os->prettyName);
         else
             buildOutputDefault(os, &result);
 
+        //Append architecture if it is missing
+        if(!ffStrbufContainIgnCase(&result, &instance.state.platform.sysinfo.architecture))
+        {
+            ffStrbufAppendC(&result, ' ');
+            ffStrbufAppend(&result, &instance.state.platform.sysinfo.architecture);
+        }
+
         ffPrintLogoAndKey(FF_OS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT);
         ffStrbufPutTo(&result, stdout);
     }
     else
     {
-        FF_PRINT_FORMAT_CHECKED(FF_OS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, FF_OS_NUM_FORMAT_ARGS, ((FFformatarg[]){
+        FF_PRINT_FORMAT_CHECKED(FF_OS_MODULE_NAME, 0, &options->moduleArgs, FF_PRINT_TYPE_DEFAULT, ((FFformatarg[]){
             FF_FORMAT_ARG(instance.state.platform.sysinfo.name, "sysname"),
             FF_FORMAT_ARG(os->name, "name"),
             FF_FORMAT_ARG(os->prettyName, "pretty-name"),
@@ -186,37 +159,33 @@ void ffGenerateOSJsonResult(FF_MAYBE_UNUSED FFOSOptions* options, yyjson_mut_doc
     yyjson_mut_obj_add_strbuf(doc, obj, "versionID", &os->versionID);
 }
 
-void ffPrintOSHelpFormat(void)
-{
-    FF_PRINT_MODULE_FORMAT_HELP_CHECKED(FF_OS_MODULE_NAME, "{3} {10} {12}", FF_OS_NUM_FORMAT_ARGS, ((const char* []) {
-        "Name of the kernel (Linux, WIN32_NT, Darwin, FreeBSD) - sysname",
-        "Name of the OS - name",
-        "Pretty name of the OS - pretty-name",
-        "ID of the OS - id",
-        "ID like of the OS - id-like",
-        "Variant of the OS - variant",
-        "Variant ID of the OS - variant-id",
-        "Version of the OS - version",
-        "Version ID of the OS - version-id",
-        "Version codename of the OS - codename",
-        "Build ID of the OS - build-id",
-        "Architecture of the OS - arch",
-    }));
-}
+static FFModuleBaseInfo ffModuleInfo = {
+    .name = FF_OS_MODULE_NAME,
+    .description = "Print operating system name and version",
+    .parseCommandOptions = (void*) ffParseOSCommandOptions,
+    .parseJsonObject = (void*) ffParseOSJsonObject,
+    .printModule = (void*) ffPrintOS,
+    .generateJsonResult = (void*) ffGenerateOSJsonResult,
+    .generateJsonConfig = (void*) ffGenerateOSJsonConfig,
+    .formatArgs = FF_FORMAT_ARG_LIST(((FFModuleFormatArg[]) {
+        {"Name of the kernel", "sysname"},
+        {"Name of the OS", "name"},
+        {"Pretty name of the OS, if available", "pretty-name"},
+        {"ID of the OS", "id"},
+        {"ID like of the OS", "id-like"},
+        {"Variant of the OS", "variant"},
+        {"Variant ID of the OS", "variant-id"},
+        {"Version of the OS", "version"},
+        {"Version ID of the OS", "version-id"},
+        {"Version codename of the OS", "codename"},
+        {"Build ID of the OS", "build-id"},
+        {"Architecture of the OS", "arch"},
+    }))
+};
 
 void ffInitOSOptions(FFOSOptions* options)
 {
-    ffOptionInitModuleBaseInfo(
-        &options->moduleInfo,
-        FF_OS_MODULE_NAME,
-        "Print operating system name and version",
-        ffParseOSCommandOptions,
-        ffParseOSJsonObject,
-        ffPrintOS,
-        ffGenerateOSJsonResult,
-        ffPrintOSHelpFormat,
-        ffGenerateOSJsonConfig
-    );
+    options->moduleInfo = ffModuleInfo;
     ffOptionInitModuleArg(&options->moduleArgs,
         #ifdef _WIN32
             ""
@@ -224,10 +193,10 @@ void ffInitOSOptions(FFOSOptions* options)
             ""
         #elif __FreeBSD__
             "󰣠"
-        #elif __linux__
-            ""
         #elif __ANDROID__
             ""
+        #elif __linux__
+            ""
         #elif __sun
             ""
         #elif __OpenBSD__
