@@ -50,6 +50,7 @@ void ffPrintPackages(FFPackagesOptions* options)
         FF_PRINT_PACKAGE_NAME(nixDefault, "nix-default")
         FF_PRINT_PACKAGE(apk)
         FF_PRINT_PACKAGE(pkg)
+        FF_PRINT_PACKAGE(pkgsrc)
         FF_PRINT_PACKAGE_NAME(flatpakSystem, counts.flatpakUser ? "flatpak-system" : "flatpak")
         FF_PRINT_PACKAGE_NAME(flatpakUser, "flatpak-user")
         FF_PRINT_PACKAGE(snap)
@@ -121,6 +122,7 @@ void ffPrintPackages(FFPackagesOptions* options)
             FF_FORMAT_ARG(counts.mport, "mport"),
             FF_FORMAT_ARG(counts.qi, "qi"),
             FF_FORMAT_ARG(counts.amUser, "am-user"),
+            FF_FORMAT_ARG(counts.pkgsrc, "pkgsrc"),
             FF_FORMAT_ARG(nixAll, "nix-all"),
             FF_FORMAT_ARG(flatpakAll, "flatpak-all"),
             FF_FORMAT_ARG(brewAll, "brew-all"),
@@ -197,6 +199,7 @@ bool ffParsePackagesCommandOptions(FFPackagesOptions* options, const char* key,
                     FF_TEST_PACKAGE_NAME(PALUDIS)
                     FF_TEST_PACKAGE_NAME(PKG)
                     FF_TEST_PACKAGE_NAME(PKGTOOL)
+                    FF_TEST_PACKAGE_NAME(PKGSRC)
                     break;
                 case 'Q': if (false);
                     FF_TEST_PACKAGE_NAME(QI)
@@ -311,6 +314,7 @@ void ffParsePackagesJsonObject(FFPackagesOptions* options, yyjson_val* module)
                             FF_TEST_PACKAGE_NAME(PALUDIS)
                             FF_TEST_PACKAGE_NAME(PKG)
                             FF_TEST_PACKAGE_NAME(PKGTOOL)
+                            FF_TEST_PACKAGE_NAME(PKGSRC)
                             break;
                         case 'Q': if (false);
                             FF_TEST_PACKAGE_NAME(QI)
@@ -373,6 +377,7 @@ void ffGeneratePackagesJsonConfig(FFPackagesOptions* options, yyjson_mut_doc* do
         FF_TEST_PACKAGE_NAME(PALUDIS)
         FF_TEST_PACKAGE_NAME(PKG)
         FF_TEST_PACKAGE_NAME(PKGTOOL)
+        FF_TEST_PACKAGE_NAME(PKGSRC)
         FF_TEST_PACKAGE_NAME(QI)
         FF_TEST_PACKAGE_NAME(RPM)
         FF_TEST_PACKAGE_NAME(SCOOP)
@@ -427,6 +432,7 @@ void ffGeneratePackagesJsonResult(FF_MAYBE_UNUSED FFPackagesOptions* options, yy
     FF_APPEND_PACKAGE_COUNT(paludis)
     FF_APPEND_PACKAGE_COUNT(pkg)
     FF_APPEND_PACKAGE_COUNT(pkgtool)
+    FF_APPEND_PACKAGE_COUNT(pkgsrc)
     FF_APPEND_PACKAGE_COUNT(qi)
     FF_APPEND_PACKAGE_COUNT(macports)
     FF_APPEND_PACKAGE_COUNT(rpm)
@@ -484,6 +490,7 @@ static FFModuleBaseInfo ffModuleInfo = {
         {"Number of mport packages", "mport"},
         {"Number of qi packages", "qi"},
         {"Number of am-user (aka appman) packages", "am-user"},
+        {"Number of pkgsrc packages", "pkgsrc"},
         {"Total number of all nix packages", "nix-all"},
         {"Total number of all flatpak app packages", "flatpak-all"},
         {"Total number of all brew packages", "brew-all"},
